@@ -6,4 +6,6 @@ __version__ = '0.0.11'
 
 from artific.artific import BubbleSort as BubbleSort
 from artific.artific import InsertionSort as InsertionSort
-from artific.artific import HeapSort as HeapSort
\ No newline at end of file
+from artific.artific import HeapSort as HeapSort
+from artific.artific import BinarySearch as BinarySearch
+from artific.artific import LinearSearch as LinearSearch
\ No newline at end of file
